==> geant4.10.00.tar.gz: geant4.10.00/source/processes/hadronic/models/cascade/cascade/src/G4VCascadeCollider.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4VCascadeCollider.cc 66241 2012-12-13 18:34:42Z gunter $
//
// 20100615  M. Kelsey -- Split constructor to have verbose separately
// 20100623  M. Kelsey -- Use old bindingEnergy() wrapper (now returns
//		G4NucleiProperties::GetBindingEnergy()).
// 20100714  M. Kelsey -- Move concrete functions to G4CascadeColliderBase

#include "G4VCascadeCollider.hh"
#include "G4ios.hh"


// Constructor handles verbose announcement

G4VCascadeCollider::G4VCascadeCollider(const char* name, G4int verbose)
  : theName(name), verboseLevel(verbose) {
  if (verboseLevel) G4cout << " >>> " << theName << " ctor " << G4endl;
}

==> geant4.10.03.p03.tar.gz: geant4.10.03.p03/source/processes/hadronic/models/cascade/cascade/src/G4VCascadeCollider.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4VCascadeCollider.cc 66241 2012-12-13 18:34:42Z gunter $
//
// 20100615  M. Kelsey -- Split constructor to have verbose separately
// 20100623  M. Kelsey -- Use old bindingEnergy() wrapper (now returns
//		G4NucleiProperties::GetBindingEnergy()).
// 20100714  M. Kelsey -- Move concrete functions to G4CascadeColliderBase
// 20140930  Change name from "const char*" to "const G4String"

#include "G4VCascadeCollider.hh"
#include "G4ios.hh"


// Constructor handles verbose announcement

G4VCascadeCollider::G4VCascadeCollider(const G4String& name, G4int verbose)
  : theName(name), verboseLevel(verbose) {
  if (verboseLevel) G4cout << " >>> " << theName << " ctor " << G4endl;
}
